@@ -818,16 +818,19 @@ class MTurkServicesWrapper(object):
         if block_qualification_ids is None:
             block_qualification_ids = []
 
-        require_quals = self.config.get('HIT Configuration', 'require_quals', fallback=None)
+        key = f'require_quals_{self.mode}'
+        require_quals = self.config.get('HIT Configuration', key, fallback=None)
         if require_quals:
             require_qualification_ids.extend(require_quals.split(','))
 
-        block_quals = self.config.get('HIT Configuration', 'block_quals', fallback=None)
+        key = f'block_quals_{self.mode}'
+        block_quals = self.config.get('HIT Configuration', key, fallback=None)
         if block_quals:
             block_qualification_ids.extend(block_quals.split(','))
-        
-        advanced_quals_path = self.config.get('HIT Configuration', 'advanced_quals_path', fallback=None)
-        advanced_qualifications = []
+
+        key = f'advanced_quals_path_{self.mode}'
+        advanced_quals_path = self.config.get('HIT Configuration', key, fallback=None)
+        advanced_qualifications = [] # default
         if advanced_quals_path:
             with open(advanced_quals_path) as f:
                 advanced_qualifications = json.load(f)
